<?php
remove_action( 'give_single_form_summary', 'give_template_single_title', 5 );
/**
 * Social Charity functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package social_charity
 */

if ( ! function_exists( 'social_charity_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function social_charity_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Social Charity, use a find and replace
		 * to change 'social-charity' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'social-charity', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'social-charity-banner-1135*666', 1135, 666, true );
		add_image_size( 'social-charity-causes-image', false, 214, true );
		add_image_size( 'social-charity-who-we-are-image', false, 337, true );
		add_image_size( 'social-charity-events-image', false, 174, true );
		add_image_size( 'social-charity-testimonials-image', 117, 117, true );
		add_image_size( 'social-charity-gallery-image', false, 170, true );
		add_image_size( 'social-charity-blog-image', false, 209, true );
		
		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'social-charity' ),
			'quick-links' => esc_html__('Footer(Quick Links)','social-charity')
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'social_charity_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );
		
		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'social_charity_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function social_charity_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'social_charity_content_width', 640 );
}
add_action( 'after_setup_theme', 'social_charity_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function social_charity_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'social-charity' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'social-charity' ),
		'before_widget' => '<div id="%1$s" class=" block widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="title widget-title">',
		'after_title'   => '</h4>',
	) );


	register_sidebar( array(
		'name'          => esc_html__( 'Footer widget 1', 'social-charity' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'social-charity' ),
		'before_widget' => '<div id="%1$s" class="f-about widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '',
		'after_title'   => '',
	) );


	register_sidebar( array(
		'name'          => esc_html__( 'Footer widget 2', 'social-charity' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widgets here.', 'social-charity' ),
		'before_widget' => '<div id="%1$s" class="quick-links widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="f-title widget-title">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer widget 3', 'social-charity' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widgets here.', 'social-charity' ),
		'before_widget' => '<div id="%1$s" class="recent-news widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="f-title widget-title">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer widget 4', 'social-charity' ),
		'id'            => 'footer-4',
		'description'   => esc_html__( 'Add widgets here.', 'social-charity' ),
		'before_widget' => '<div id="%1$s" class="contact-form widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="f-title widget-title">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => __( 'Google map iframe', 'social-charity' ),
		'id'            => 'google-map',
		'description'   => __( 'Add widgets here.', 'social-charity' ),
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'social_charity_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
require get_template_directory(). '/inc/enqueue.php';


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';


/**
 * Bootstrap Navwalker
 */
require get_template_directory() . '/inc/wp-bootstrap-navwalker.php';


require get_template_directory() . '/inc/customizer/customizer-partials-function.php';


require_once get_template_directory() . '/inc/breadcrumbs.php';


if ( is_admin() ) {
	// Load about.
	
	require_once trailingslashit( get_template_directory() ) . 'inc/theme-info/class-about.php';
	require_once trailingslashit( get_template_directory() ) . 'inc/theme-info/about.php';

}

function social_charity_check_wp_give_plugin_activation()
{
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	return is_plugin_active( 'give/give.php' );
}


/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}