<?php
/**
 * About configuration
 *
 * @package Social_Charity
 */

$config = array(
	'menu_name' => esc_html__( 'Social Charity Setup', 'social-charity' ),
	'page_name' => esc_html__( 'Social Charity Setup', 'social-charity' ),

	/* translators: theme version */
	'welcome_title' => sprintf( esc_html__( 'Welcome to %s - ', 'social-charity' ), 'Social Charity' ),

	/* translators: 1: theme name */
	'welcome_content' => sprintf( esc_html__( 'We hope this page will help you to setup %1$s with few clicks. We believe you will find it easy to use and perfect for your website development.', 'social-charity' ), 'Social Charity' ),

	// Quick links.
	'quick_links' => array(
		'theme_url' => array(
			'text' => esc_html__( 'Theme Details','social-charity' ),
			'url'  => 'http://html5wp.com/downloads/social-charity-wordpress-theme/',
		),
		'demo_url' => array(
			'text' => esc_html__( 'View Demo','social-charity' ),
			'url'  => 'https://www.themefie.com/wp/ngocharitypro/',
		),
		'documentation_url' => array(
			'text'   => esc_html__( 'Documentation','social-charity' ),
			'url'    => 'http://themefie.com/docs/social-charity-pro.pdf',
		),
		'upgrade_url' => array(
			'text'   => esc_html__( 'Upgrade to Pro','social-charity' ),
			'url'    => 'http://html5wp.com/downloads/social-charity-pro/',
			'button' => 'primary'
		),
	),

	// Tabs.
	'tabs' => array(
		'getting_started'     => esc_html__( 'Getting Started', 'social-charity' ),
		'recommended_actions' => esc_html__( 'Recommended Actions', 'social-charity' ),
		'support'             => esc_html__( 'Support', 'social-charity' ),
	),

	// Getting started.
	'getting_started' => array(
		array(
			'title'               => esc_html__( 'Theme Documentation', 'social-charity' ),
			'text'                => esc_html__( 'Find step by step instructions to setup theme easily.', 'social-charity' ),
			'button_label'        => esc_html__( 'View documentation', 'social-charity' ),
			'button_link'         => 'http://themefie.com/docs/social-charity-pro.pdf',
			'is_button'           => true,
			'recommended_actions' => false,
			'is_new_tab'          => true,
		),
		array(
			'title'               => esc_html__( 'Recommended Actions', 'social-charity' ),
			'text'                => esc_html__( 'We recommend few steps to take so that you can get complete site like shown in demo.', 'social-charity' ),
			'button_label'        => esc_html__( 'Check recommended actions', 'social-charity' ),
			'button_link'         => esc_url( admin_url( 'themes.php?page=social-charity-about&tab=recommended_actions' ) ),
			'is_button'           => true,
			'recommended_actions' => false,
			'is_new_tab'          => false,
		),
		array(
			'title'               => esc_html__( 'Customize Everything', 'social-charity' ),
			'text'                => esc_html__( 'Start customizing every aspect of the website with customizer.', 'social-charity' ),
			'button_label'        => esc_html__( 'Go to Customizer', 'social-charity' ),
			'button_link'         => esc_url( wp_customize_url() ),
			'is_button'           => true,
			'recommended_actions' => false,
			'is_new_tab'          => false,
		),
	),

	// Recommended actions.
	'recommended_actions' => array(
		'content' => array(
			'front-page' => array(
				'title'       => esc_html__( 'Setting Static Front Page','social-charity' ),
				'description' => esc_html__( 'Create a new page to display on front page ( Ex: Home ) and assign "Home" template. Select A static page then Front page and Posts page to display front page specific sections. Note: Static page will be set automatically when you import demo content.', 'social-charity' ),
				'id'          => 'front-page',
				'check'       => ( 'page' === get_option( 'show_on_front' ) ) ? true : false,
				'help'        => '<a href="' . esc_url( wp_customize_url() ) . '?autofocus[section]=static_front_page" class="button button-secondary">' . esc_html__( 'Static Front Page', 'social-charity' ) . '</a>',
			),
			'contact-form-7' => array(
				'title'       => esc_html__( 'Contact Form 7', 'social-charity' ),
				'description' => esc_html__( 'Please install the Contact Form 7 plugin Before Importing Demo.', 'social-charity' ),
				'check'       => class_exists( 'OCDI_Plugin' ),
				'plugin_slug' => 'contact-form-7',
				'id'          => 'contact-form-7',
			),
			'newsletter' => array(
				'title'       => esc_html__( 'NewsLetter Plugin', 'social-charity' ),
				'description' => esc_html__( 'Please install the Newsletter Plugin Before Importing Demo.', 'social-charity' ),
				'check'       => class_exists( 'OCDI_Plugin' ),
				'plugin_slug' => 'newsletter',
				'id'          => 'newsletter',
			),

			'give' => array(
				'title'       => esc_html__( 'Give', 'social-charity' ),
				'description' => esc_html__( 'Please install the GiveDonation Plugin and Fundraising Platform) plugin to import the demo content. After activation go to Appearance >> Import Demo Data and import it.', 'social-charity' ),
				'check'       => class_exists( 'OCDI_Plugin' ),
				'plugin_slug' => 'give',
				'id'          => 'give',
			),
			'one-click-demo-import' => array(
				'title'       => esc_html__( 'One Click Demo Import', 'social-charity' ),
				'description' => esc_html__( 'Please install the One Click Demo Import plugin to import the demo content. After activation go to Appearance >> Import Demo Data and import it.', 'social-charity' ),
				'check'       => class_exists( 'OCDI_Plugin' ),
				'plugin_slug' => 'one-click-demo-import',
				'id'          => 'one-click-demo-import',
			),
			'custom-registration-form-builder-with-submission-manager' => array(
				'title'       => esc_html__( 'RegistrationMagic – Custom Registration Forms and User Login', 'social-charity' ),
				'description' => esc_html__( 'Please install the custom Registration Forms and User Login Plugin Before Importing Demo', 'social-charity' ),
				'check'       => class_exists( 'OCDI_Plugin' ),
				'plugin_slug' => 'custom-registration-form-builder-with-submission-manager',
				'id'          => 'custom-registration-form-builder-with-submission-manager',
			),
			'profilegrid-user-profiles-groups-and-communities' => array(
				'title'       => esc_html__( 'RegistrationMagic – Custom Registration Forms and User Login', 'social-charity' ),
				'description' => esc_html__( 'Please install the User Profiles, Groups and Communities Plugin Before Importing Demo', 'social-charity' ),
				'check'       => class_exists( 'OCDI_Plugin' ),
				'plugin_slug' => 'profilegrid-user-profiles-groups-and-communities',
				'id'          => 'profilegrid-user-profiles-groups-and-communities',
			),
		),
	),

	// Support.
	'support_content' => array(
		'first' => array(
			'title'        => esc_html__( 'Contact Support', 'social-charity' ),
			'icon'         => 'dashicons dashicons-sos',
			'text'         => esc_html__( 'If you have any problem, feel free to create ticket on our dedicated Support forum.', 'social-charity' ),
			'button_label' => esc_html__( 'Contact Support', 'social-charity' ),
			'button_link'  => esc_url( 'http://html5wp.com/downloads/social-charity-wordpress-theme/' ),
			'is_button'    => true,
			'is_new_tab'   => true,
		),
		'second' => array(
			'title'        => esc_html__( 'Theme Documentation', 'social-charity' ),
			'icon'         => 'dashicons dashicons-book-alt',
			'text'         => esc_html__( 'Kindly check our theme documentation for detailed information and video instructions.', 'social-charity' ),
			'button_label' => esc_html__( 'View Documentation', 'social-charity' ),
			'button_link'  => 'http://themefie.com/docs/social-charity-pro.pdf',
			'is_button'    => true,
			'is_new_tab'   => true,
		),
		'third' => array(
			'title'        => esc_html__( 'Customization Request', 'social-charity' ),
			'icon'         => 'dashicons dashicons-admin-tools',
			'text'         => esc_html__( 'This is 100% free theme and has premium version.Either Upgrade to Pro or  Feel free to contact us any time if you need any customization service.', 'social-charity' ),
			'button_label' => esc_html__( 'Upgrade to Pro', 'social-charity' ),
			'button_link'  => 'http://html5wp.com/downloads/social-charity-pro/',
			'is_button'    => true,
			'is_new_tab'   => true,
		),
	),


);
Social_Charity_About::init( apply_filters( 'social_charity_about_filter', $config ) );